:orphan:

Welcome to Mixer
================

.. == logo ==
.. image:: _static/logo.png
    :width: 100

Welcome to Mixer's documentation.

.. == description ==
.. _description:
.. automodule:: mixer

.. == badges ==
.. _badges:
.. include:: ../README.rst
    :start-after: .. _badges:
    :end-before: .. _documentation:

User's Guide
------------

This part of the documentation will show you how to get started in using Mixer.

.. toctree::
   :maxdepth: 2

   installation
   quickstart
..   django
..   flask
..   sqlalchemy


API Reference
-------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


.. == bugtracker ==
.. _bugtracker:
.. include:: ../README.rst
    :start-after: .. _bugtracker:
    :end-before: Contributing


.. == contributing ==
.. _contributing:
.. include:: ../README.rst
    :start-after: Contributing
    :end-before: Contributors


.. == contributors ==
.. _contributors:
.. include:: ../README.rst
    :start-after: Contributors
    :end-before: .. _license:


.. == links ==
.. _links:
.. include:: ../README.rst
    :start-after: .. _links:
